@@ -31,6 +31,7 @@
 #include <gtk/gtksignal.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gnome-canvas-pixbuf.h>
+#include <gal/e-table/e-table-specification.h>
 
 #include "checked.xpm"
 #include "unchecked.xpm"
@@ -218,16 +219,18 @@ xst_ui_option_menu_get_selected_row (GtkOptionMenu *option_menu)
 gchar *
 xst_ui_option_menu_get_selected_string (GtkOptionMenu *option_menu)
 {
-	gchar *buf = NULL;
+	gchar *buf;
 	
 	if (GTK_BIN (option_menu)->child) {
 		GtkWidget *child = GTK_BIN (option_menu)->child;
 		
-		if (GTK_IS_LABEL (child))
+		if (GTK_IS_LABEL (child)) {
 			gtk_label_get (GTK_LABEL (child), &buf);
+			return g_strdup (buf);
+		}		
 	}
 
-	return buf;
+	return NULL;
 }
 
 void
@@ -413,3 +416,92 @@ xst_ui_ctree_get_checkmark (GtkCTree *ctree, GtkCTreeNode *node, gint column)
 	if (pixmap == checked_pixmap) return (TRUE);
 	return (FALSE);
 }
+
+/**
+ * xst_ui_load_etspec:
+ * @common_path: Usually tool->etspecs_common_path
+ * @name: name of spec file.
+ * 
+ * Load ETableSpecification from given filename, return it as a string.
+ * Checks if given spec file is valid.
+ * 
+ * Return Value: String containing ETableSpecification or NULL one error.
+ **/
+gchar *
+xst_ui_load_etspec (const gchar *common_path, const gchar *name)
+{
+	ETableSpecification *specification;
+	gchar *table_spec = NULL;
+	gchar *path;
+
+	g_return_val_if_fail (common_path != NULL, NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+
+	if (common_path[strlen (common_path) - 1] != '/')
+		path = g_strconcat (common_path, "/", name, NULL);
+	else
+		path = g_strconcat (common_path, name, NULL);
+	
+	specification = e_table_specification_new();
+	if (e_table_specification_load_from_file(specification, path))
+		table_spec = e_table_specification_save_to_string (specification);
+	else
+		g_warning ("xst_ui_load_etspec: Cant' load ETable specification from %s.", path);
+	
+	gtk_object_unref(GTK_OBJECT(specification));
+	g_free (path);
+	
+	return table_spec;
+}
+
+/**
+ * xst_ui_entry_set_text:
+ * @entry: GtkEntry to set to
+ * @str: string to set
+ *
+ * Simple wrapper around gtk_entry_set_text. Sets entry text to "" if str == NULL
+ * 
+ **/
+void
+xst_ui_entry_set_text (void *entry, const gchar *str)
+{
+	g_return_if_fail (entry != NULL);
+	g_return_if_fail (GTK_IS_ENTRY (entry));
+	
+	gtk_entry_set_text (GTK_ENTRY (entry), (str)? str: "");
+}
+
+/**
+ * xst_ui_logout_dialog:
+ * @void: 
+ * 
+ * Asks user for confirmation and restarts X server.
+ * 
+ * Return Value: TRUE if logout, FALSE if not.
+ **/
+gboolean
+xst_ui_logout_dialog (void)
+{
+	GtkWidget *dialog;
+	gint retval;
+	GnomeClient *client = gnome_master_client ();
+
+	dialog = gnome_question_dialog (N_("You are about to logout from\n"
+					   "your graphical session.\n"
+					   "It is recommended you close all\n"
+					   "your running programs.\n\n"
+					   "Restart now?"),
+					NULL, NULL);
+
+	retval = gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+
+	if (retval)
+		return FALSE;
+
+	/* Yes, let's end our gnome-session. */
+	
+	gnome_client_request_save (client, GNOME_SAVE_BOTH,
+				   TRUE, GNOME_INTERACT_ERRORS, FALSE, TRUE);
+
+	return TRUE;
+}
