@@ -7,7 +7,7 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gnome-canvas-pixbuf.h>
 
-#include "global.h"
+#include "xst.h"
 
 #include "callbacks.h"
 #include "transfer.h"
@@ -34,7 +34,9 @@ main (int argc, char *argv[])
 {
 	GtkWidget *w0;
 
-	tool = xst_tool_init ("disks", _("Disk Partitions"), argc, argv, NULL);
+	xst_init ("disks-admin", argc, argv, NULL);
+	tool = xst_tool_new ();
+	xst_tool_construct (tool, "disks", _("Disk Partitions"));
 
 	xst_tool_set_xml_funcs (tool, transfer_xml_to_gui, transfer_gui_to_xml, NULL);
 	xst_dialog_connect_signals (tool->main_dialog, signals);
@@ -44,7 +46,7 @@ main (int argc, char *argv[])
 	w0 = xst_dialog_get_widget (tool->main_dialog, "disks");
 	gtk_ctree_set_indent (GTK_CTREE (w0), 16);
 
-	xst_tool_main (tool);
+	xst_tool_main (tool, FALSE);
 
 	return 0;
 }
