@@ -41,13 +41,13 @@ struct _XstNetworkInterfaceDescription {
 };
 
 static const XstNetworkInterfaceDescription xst_iface_desc [] = {
-	{ N_("Other type"),                   XST_CONNECTION_OTHER,   "networking.png",  "other_type"},
+	{ N_("Other type"),                   XST_CONNECTION_OTHER,   "network.png",  "other_type"},
 	{ N_("Ethernet LAN card"),            XST_CONNECTION_ETH,     "16_ethernet.xpm", "eth"   },
-	{ N_("WaveLAN wireless LAN"),         XST_CONNECTION_WVLAN,   "networking.png",  "wvlan" },
+	{ N_("WaveLAN wireless LAN"),         XST_CONNECTION_WVLAN,   "network.png",  "wvlan" },
 	{ N_("PPP: modem or transfer cable"), XST_CONNECTION_PPP,     "16_ppp.xpm",      "ppp"   },
 	{ N_("Parallel line"),                XST_CONNECTION_PLIP,    "16_plip.xpm",  "plip"  },
 	{ N_("Loopback: virtual interface"),  XST_CONNECTION_LO,      "16_loopback.xpm", "lo"    },
-	{ N_("Unknown type"),                 XST_CONNECTION_UNKNOWN, "networking.png",  NULL},
+	{ N_("Unknown type"),                 XST_CONNECTION_UNKNOWN, "network.png",  NULL},
 	{ NULL, XST_CONNECTION_UNKNOWN, NULL, NULL}
 };
 
@@ -67,7 +67,7 @@ static void on_ppp_update_dns_toggled (GtkWidget *w, XstConnection *cxn);
 #define GET_STR(yy_prefix,xx) g_free (cxn->xx); cxn->xx = gtk_editable_get_chars (GTK_EDITABLE (W (yy_prefix#xx)), 0, -1)
 #define GET_BOOL(yy_prefix,xx) cxn->xx = GTK_TOGGLE_BUTTON (W (yy_prefix#xx))->active
 #define GET_BOOL_NOT(yy_prefix,xx) GET_BOOL(yy_prefix,xx); cxn->xx = !cxn->xx;
-#define SET_STR(yy_prefix,xx) my_entry_set_text (GTK_ENTRY (W (yy_prefix#xx)), cxn->xx)
+#define SET_STR(yy_prefix,xx) xst_ui_entry_set_text (GTK_ENTRY (W (yy_prefix#xx)), cxn->xx)
 #define SET_BOOL(yy_prefix,xx) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (W (yy_prefix#xx)), cxn->xx)
 #define SET_BOOL_NOT(yy_prefix,xx) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (W (yy_prefix#xx)), !cxn->xx)
 	
@@ -101,10 +101,16 @@ my_get_widget (GladeXML *glade, const gchar *name)
 	return w;
 }
 
-static void
-my_entry_set_text (GtkEntry *w, gchar *txt)
+static gint
+my_strcmp (gchar *a, gchar *b)
 {
-	gtk_entry_set_text (w, (txt)? txt: "");
+	if (!a)
+		a = "";
+
+	if (!b)
+		b = "";
+
+	return strcmp (a, b);
 }
 
 static gboolean
@@ -444,14 +450,14 @@ connection_clist_cmp (GtkCList *clist, gconstpointer p1, gconstpointer p2)
 	gint res;
 
 	/* Compare dev cols */
-	res = strcmp (connection_get_cell_text (p1, 0),
-		      connection_get_cell_text (p2, 0));
+	res = my_strcmp (connection_get_cell_text (p1, 0),
+			 connection_get_cell_text (p2, 0));
 	if (res)
 		return res;
 
 	/* Compare comment cols */
-	return strcmp (connection_get_cell_text (p1, 2),
-		       connection_get_cell_text (p2, 2));
+	return my_strcmp (connection_get_cell_text (p1, 2),
+			  connection_get_cell_text (p2, 2));
 }
 
 static void
@@ -854,8 +860,64 @@ empty_ptp (XstConnection *cxn)
 	}
 }
 
+static gboolean
+strempty (gchar *str)
+{
+	return (!str || !*str);
+}
+
+static gboolean
+connection_validate (XstConnection *cxn)
+{
+	gchar *error = NULL;
+	
+	switch (cxn->type) {
+	case XST_CONNECTION_ETH:
+	case XST_CONNECTION_WVLAN:
+	case XST_CONNECTION_UNKNOWN:
+		if (cxn->ip_config == IP_MANUAL &&
+		    (strempty (cxn->address) ||
+		     strempty (cxn->netmask)))
+			error = _("The IP address or netmask for the interface\n"
+				  "was left empty. Please enter valid IP\n"
+				  "addresses in those fields to continue.");
+		break;
+	case XST_CONNECTION_PLIP:
+		if (strempty (cxn->address) ||
+		    strempty (cxn->remote_address))
+			error = _("The IP address or remote address for the\n"
+				  "interface was left empty. Please enter valid\n"
+				  "IP addresses in those fields to continue.");
+		break;
+	case XST_CONNECTION_PPP:
+		if (!cxn->update_dns && strempty (cxn->dns1))
+			error = _("You chose to set the DNS servers for this\n"
+				  "connection manually, but left the IP\n"
+				  "address for the primary DNS empty. Please\n"
+				  "enter the IP for the primary DNS or uncheck\n"
+				  "the manual DNS option.");
+		break;
+	default:
+		break;
+	}
+
+	if (error) {
+		GtkWidget *message;
+		
+		message = gnome_message_box_new (error, GNOME_MESSAGE_BOX_WARNING,
+						 GNOME_STOCK_BUTTON_OK,
+						 NULL);
+		if (cxn->window)
+			gnome_dialog_set_parent (GNOME_DIALOG (message), GTK_WINDOW (cxn->window));
+		gnome_dialog_run_and_close (GNOME_DIALOG (message));
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
 static void
-connection_config_save (XstConnection *cxn)
+connection_empty_gui (XstConnection *cxn)
 {
 	empty_general (cxn);
 
@@ -875,18 +937,43 @@ connection_config_save (XstConnection *cxn)
 		empty_ip (cxn);
 		break;
 	}
+}	
 
+static gboolean
+connection_config_save (XstConnection *cxn)
+{
+	XstConnection *tmp = g_new0 (XstConnection, 1);
+
+	tmp->window = cxn->window;
+	tmp->xml = cxn->xml;
+	tmp->type = cxn->type;
+	tmp->modified = cxn->modified;
+	tmp->creating = cxn->creating;
+	tmp->frozen = cxn->frozen;
+	tmp->ip_config = cxn->ip_config;
+	tmp->tmp_ip_config = cxn->tmp_ip_config;
+	
+	connection_empty_gui (tmp);
+	if (!connection_validate (tmp)) {
+		connection_free (tmp);
+		return FALSE;
+	}
+
+	connection_empty_gui (cxn);
 	connection_set_modified (cxn, FALSE);
-	connection_update_row (cxn);	
+	connection_update_row (cxn);
+
+	return TRUE;
 }
 
 static void
 on_connection_ok_clicked (GtkWidget *w, XstConnection *cxn)
 {
-	cxn->creating = FALSE;
+	if (connection_config_save (cxn))
+		gtk_widget_destroy (cxn->window);
+		
 	if (cxn->modified)
-		connection_config_save (cxn);
-	gtk_widget_destroy (cxn->window);
+		cxn->creating = FALSE;
 }
 
 static void
@@ -1094,13 +1181,13 @@ hookup_callbacks (XstConnection *cxn)
 	};
 	struct { char *name; EditableFilterRules rule; }
 	s[] = {
-		{ "ip_address",          EF_ALLOW_NONE },
-		{ "ip_netmask",          EF_ALLOW_NONE },
-		{ "ip_gateway",          EF_ALLOW_NONE },
-		{ "ppp_dns1",            EF_ALLOW_NONE },
-		{ "ppp_dns2",            EF_ALLOW_NONE },
-		{ "ptp_address",         EF_ALLOW_NONE },
-		{ "ptp_remote_address",  EF_ALLOW_NONE },
+		{ "ip_address",          EF_ALLOW_IP },
+		{ "ip_netmask",          EF_ALLOW_IP },
+		{ "ip_gateway",          EF_ALLOW_IP },
+		{ "ppp_dns1",            EF_ALLOW_IP },
+		{ "ppp_dns2",            EF_ALLOW_IP },
+		{ "ptp_address",         EF_ALLOW_IP },
+		{ "ptp_remote_address",  EF_ALLOW_IP },
 		{ NULL,                  EF_ALLOW_NONE }
 	};
 
