@@ -99,21 +99,6 @@ enum
 	OPTION_MENU_TYPE_NFS
 };
 
-/**
- * set_text_or_blank: Sets a GtkEntry to the supplied text value, which can be NULL.
- *
- * If the text reference is NULL, the entry is set to an empty string.
- */
-
-static void
-set_text_or_blank (GtkEntry *entry, const gchar *text)
-{
-	if (text)
-		gtk_entry_set_text (entry, text);
-	else
-		gtk_entry_set_text (entry, "");
-}
-
 /**
  * export_settings_set_type: Change appearance of the export settings dialog.
  * @type: EXPORT_SETTINGS_TYPE_SMB (SMB) or EXPORT_SETTINGS_TYPE_NFS (NFS).
@@ -241,9 +226,9 @@ export_settings_set_configuration (ExportSettingsConfiguration *c)
 
 	export_settings_get_widgets (&w);
 
-	set_text_or_blank            (w.name,           c->name);
-	set_text_or_blank            (w.path,           c->path);
-	set_text_or_blank            (w.comment,        c->comment);
+	xst_ui_entry_set_text        (w.name,           c->name);
+	xst_ui_entry_set_text        (w.path,           c->path);
+	xst_ui_entry_set_text        (w.comment,        c->comment);
 
 	gtk_toggle_button_set_active (w.browseable,     c->browseable);
 	gtk_toggle_button_set_active (w.writable,       c->writable);
