@@ -41,6 +41,10 @@
 #define EXPORTS_COL_LAST        3
 #define EXPORT_CLIENTS_COL_LAST 3
 
+#define IMPORTS_TABLE_SPEC "imports.etspec"
+#define EXPORTS_TABLE_SPEC "exports.etspec"
+#define EXPORT_CLIENTS_TABLE_SPEC "export_clients.etspec"
+
 typedef gboolean  (XstValidatorFunc)(gpointer val);
 typedef gchar    *(XstFilterFunc)   (gchar *val);
 typedef void      (XstChangedFunc)  (gpointer val);
@@ -66,50 +70,17 @@ typedef struct
 }
 XstTableColDef;
 
-static void     set_mount_button_label_neg    (gboolean unmount);
+static void     set_mount_button_label_neg    (gpointer unmount);
 static void     mount_button_from_import_node (xmlNodePtr node);
-static void     export_set_writable           (gboolean writable);
+static void     export_set_writable           (gpointer writable);
 static gpointer export_get_writable           (xmlNodePtr node);
 
-#ifdef JUST_FOR_TRANSLATORS
-static char *list [] = {
-	N_("Host"),
-	N_("Path"),
-	N_("Mount Point"),
-	N_("Mounted"),
-	N_("Name"),
-	N_("Path"),
-	N_("Clients"),
-	N_("Writable"),
-	N_("Pattern"),
-	N_("Write"),
-};
-#endif
-
 extern XstTool *tool;
 
 GtkWidget *imports_table_scrolled;
 GtkWidget *exports_table_scrolled;
 GtkWidget *export_clients_table_scrolled;
 
-static const gchar *imports_spec =
-"<ETableSpecification cursor-mode='line'>"
-
-"  <ETableColumn model_col='0' _title='Host' expansion='1.0' minimum_width='40'"
-"                resizable='true' cell='string' compare='string'/>"
-
-"  <ETableColumn model_col='1' _title='Path' expansion='1.0' minimum_width='80'"
-"                resizable='true' cell='string' compare='string'/>"
-
-"  <ETableColumn model_col='2' _title='Mount Point' expansion='1.0' minimum_width='80'"
-"                resizable='true' cell='string' compare='string'/>"
-
-"  <ETableColumn model_col='3' _title='Mounted' expansion='1.0' minimum_width='16'"
-"                resizable='true' cell='checkbox' compare='integer'/>"
-
-"</ETableSpecification>";
-
-
 static const gchar *imports_basic_state =
 "<ETableState>"
 "  <column source='0'/>"
@@ -121,27 +92,6 @@ static const gchar *imports_basic_state =
 "  </grouping>"
 "</ETableState>";
 
-
-static const gchar *exports_spec =
-"<ETableSpecification cursor-mode='line'>"
-
-"  <ETableColumn model_col='0' _title='Name' expansion='1.0' minimum_width='40'"
-"                resizable='true' cell='string' compare='string'/>"
-
-"  <ETableColumn model_col='1' _title='Path' expansion='1.0' minimum_width='80'"
-"                resizable='true' cell='string' compare='string'/>"
-
-#if 0
-"  <ETableColumn model_col='2' _title='Clients' expansion='1.0' minimum_width='80'"
-"                resizable='true' cell='string' compare='string'/>"
-#endif
-
-"  <ETableColumn model_col='2' _title='Writable' expansion='1.0' minimum_width='16'"
-"                resizable='true' cell='checkbox' compare='integer'/>"
-
-"</ETableSpecification>";
-
-
 static const gchar *exports_basic_state =
 "<ETableState>"
 "  <column source='0'/>"
@@ -152,18 +102,6 @@ static const gchar *exports_basic_state =
 "  </grouping>"
 "</ETableState>";
 
-
-static const gchar *export_clients_spec =
-"<ETableSpecification cursor-mode='line'>"
-
-"  <ETableColumn model_col='0' _title='Pattern' expansion='1.0' minimum_width='40'"
-"                resizable='true' cell='string' compare='string'/>"
-
-"  <ETableColumn model_col='1' _title='Write' expansion='1.0' minimum_width='16'"
-"                resizable='true' cell='checkbox' compare='integer'/>"
-
-"</ETableSpecification>";
-
 static const gchar *export_clients_basic_state =
 "<ETableState>"
 "  <column source='0'/>"
@@ -235,6 +173,8 @@ XstWidgetUserPolicy export_clients_unselected_policies[] =
 	{ NULL }
 };
 
+static gchar *blank_string = "";
+
 static void
 set_value_at_with_col_def (ETableModel *etm, int col, int row, const void *val, void *data)
 {
@@ -314,24 +254,24 @@ value_at_with_col_def (ETableModel *etm, int col, int row, void *data)
 	else if (def->type == XST_TABLE_COL_STRING)
 	{
 		if (!node)
-			return g_strdup ("");
+			return blank_string;
 
 		node = xst_xml_element_find_first (node, def->xml_tag);
 		if (!node)
-			return g_strdup ("");
+			return blank_string;
 
-		ret = xst_xml_element_get_content (node);
+		ret = (gpointer) xst_xml_element_peek_content (node);
 	}
 	else if (def->type == XST_TABLE_COL_STRING_BLANK)
 	{
-		ret = g_strdup ("");
+		ret = blank_string;
 	}
 	else if (def->type == XST_TABLE_COL_STATE)
 	{
 		ret = (void *) xst_xml_element_get_state (node, def->xml_tag);
 	}
 	else
-		ret = g_strdup ("");
+		ret = blank_string;
 
 	return ret;
 }
@@ -410,10 +350,11 @@ export_clients_set_value_at (ETableModel *etm, int col, int row, const void *val
 	if (col > 1)
 		g_error ("Bad column passed to exports_clients_set_value_at().");
 
-#warning FIXME: Might have a memory leak here, but the input is const.
-
 	if (col == 0)
 	{
+		if (!validate_export_client_pattern ((gpointer) val))
+			return;
+
 		if (client->pattern)
 			g_free (client->pattern);
 
@@ -428,14 +369,12 @@ export_clients_set_value_at (ETableModel *etm, int col, int row, const void *val
 static void *
 export_clients_value_at (ETableModel *etm, int col, int row, void *model_data)
 {
-#warning FIXME: Does the return value get freed?
-
 	ExportClient *client;
 	void *ret;
 
 	client = e_table_memory_get_data (E_TABLE_MEMORY (etm), row);
 	if (!client)
-		return g_strdup ("");
+		return blank_string;
 
 	if (col > 1)
 		g_error ("Bad column passed to export_clients_value_at().");
@@ -443,7 +382,7 @@ export_clients_value_at (ETableModel *etm, int col, int row, void *model_data)
 	switch (col)
 	{
 	case 0:
-		ret = g_strdup (client->pattern);
+		ret = client->pattern;
 		break;
 	case 1:
 		ret = (void *) client->write;
@@ -572,9 +511,18 @@ create_imports_table (void)
 {
 	ETableScrolled *imports_table;
 	ETable *table;
+	gchar *spec;
 
+	spec = xst_conf_get_string (tool, "ispec");
+	if (!spec) {
+		spec = xst_ui_load_etspec (tool->etspecs_common_path, IMPORTS_TABLE_SPEC);
+		if (!spec)
+			g_error ("create_imports_table: Couldn't make table.");
+		xst_conf_set_string (tool, "ispec", spec);
+	}
+	
 	imports_table = create_generic_table (imports_col_count, value_at_with_col_def,
-					      set_value_at_with_col_def, imports_spec, imports_basic_state,
+					      set_value_at_with_col_def, spec, imports_basic_state,
 					      imports_table_col_def);
 
 	table = e_table_scrolled_get_table (E_TABLE_SCROLLED (imports_table));
@@ -592,9 +540,17 @@ create_exports_table (void)
 {
 	ETableScrolled *exports_table;
 	ETable *table;
+	gchar* spec;
 
+	spec = xst_conf_get_string (tool, "espec");
+	if (!spec) {
+		spec = xst_ui_load_etspec (tool->etspecs_common_path, EXPORTS_TABLE_SPEC);
+		if (!spec)
+			g_error ("create_exports_table: Couldn't make table.");
+		xst_conf_set_string (tool, "espec", spec);
+	}
 	exports_table = create_generic_table (exports_col_count, value_at_with_col_def,
-					      set_value_at_with_col_def, exports_spec, exports_basic_state,
+					      set_value_at_with_col_def, spec, exports_basic_state,
 					      exports_table_col_def);
 
 	table = e_table_scrolled_get_table (E_TABLE_SCROLLED (exports_table));
@@ -612,9 +568,18 @@ create_export_clients_table (void)
 {
 	ETableScrolled *export_clients_table;
 	ETable *table;
+	gchar* spec;
+
+	spec = xst_conf_get_string (tool, "ecspec");
+	if (!spec) {
+		spec = xst_ui_load_etspec (tool->etspecs_common_path, EXPORT_CLIENTS_TABLE_SPEC);
+		if (!spec)
+			g_error ("create_export_clients_table: Couldn't make table.");
+		xst_conf_set_string (tool, "ecspec", spec);
+	}
 
 	export_clients_table = create_generic_table (export_clients_col_count, export_clients_value_at,
-						     export_clients_set_value_at, export_clients_spec,
+						     export_clients_set_value_at, spec,
 						     export_clients_basic_state, NULL);
 
 	table = e_table_scrolled_get_table (E_TABLE_SCROLLED (export_clients_table));
@@ -778,9 +743,9 @@ set_mount_button_label (gboolean mount)
 }
 
 static void
-set_mount_button_label_neg (gboolean unmount)
+set_mount_button_label_neg (gpointer unmount)
 {
-	set_mount_button_label (!unmount);
+	set_mount_button_label (!((gboolean) unmount));
 }
 
 static void
@@ -889,18 +854,18 @@ import_table_mount_selected_node_toggle_cb (void)
 /* --- */
 
 static void
-export_set_writable (gboolean writable)
+export_set_writable (gpointer writable)
 {
 	xmlNodePtr node;
 
 	node = export_table_get_selected_node ();
-	shares_xml_export_set_general_write (node, writable);
+	shares_xml_export_set_general_write (node, (gboolean) writable);
 }
 
 static gpointer
 export_get_writable (xmlNodePtr node)
 {
-	return shares_xml_export_get_general_write (node);
+	return (gpointer) shares_xml_export_get_general_write (node);
 }
 
 void
@@ -982,7 +947,6 @@ export_clients_table_update_selected (void)
 	e_table_model_row_changed (table->model, e_table_get_cursor_row (table));
 }
 
-
 ExportClient *
 export_clients_table_get_selected (void)
 {
