@@ -38,18 +38,10 @@
 #include "callbacks.h"
 #include "user-group-xml.h"
 
-#ifdef JUST_FOR_TRANSLATORS
-static char *list [] = {
-	N_("Users"),
-	N_("UID"),
-	N_("Home"),
-	N_("Shell"),
-	N_("Comment"),
-	N_("Group"),
-	N_("GID"),
-	N_("Groups"),
-};
-#endif
+#define USER_TABLE_SPEC "users.etspec"
+#define GROUP_TABLE_SPEC "group.etspec"
+#define NET_USER_TABLE_SPEC "net_user.etspec"
+#define NET_GROUP_TABLE_SPEC "net_group.etspec"
 
 extern XstTool *tool;
 
@@ -60,43 +52,6 @@ GtkWidget *net_user_table;
 
 gint active_table;
 
-/* e-table specifications */
-
-const gchar *user_spec = "\
-<ETableSpecification cursor-mode=\"line\"> \
-  <ETableColumn model_col=\"0\" _title=\"Users\" expansion=\"1.0\" minimum_width=\"60\" resizable=\"true\" cell=\"string\" compare=\"string\"/> \
-  <ETableColumn model_col=\"1\" _title=\"UID\" expansion=\"1.0\" minimum_width=\"40\" resizable=\"true\" cell=\"string\" compare=\"id_compare\"/> \
-  <ETableColumn model_col=\"2\" _title=\"Home\" expansion=\"1.0\" minimum_width=\"80\" resizable=\"true\" cell=\"string\" compare=\"string\"/> \
-  <ETableColumn model_col=\"3\" _title=\"Shell\" expansion=\"1.0\" minimum_width=\"80\" resizable=\"true\" cell=\"string\" compare=\"string\"/> \
-  <ETableColumn model_col=\"4\" _title=\"Comment\" expansion=\"1.0\" minimum_width=\"80\" resizable=\"true\" cell=\"string\" compare=\"string\"/> \
-  <ETableColumn model_col=\"5\" _title=\"Group\" expansion=\"1.0\" minimum_width=\"80\" resizable=\"true\" cell=\"string\" compare=\"string\"/> \
-  <ETableColumn model_col=\"6\" _title=\"GID\" expansion=\"1.0\" minimum_width=\"40\" resizable=\"true\" cell=\"string\" compare=\"id_compare\"/> \
-</ETableSpecification>";
-
-const gchar *group_spec = "\
-<ETableSpecification cursor-mode=\"line\"> \
-  <ETableColumn model_col=\"0\" _title=\"Groups\" expansion=\"1.0\" minimum_width=\"60\" resizable=\"true\" cell=\"string\" compare=\"string\"/> \
-  <ETableColumn model_col=\"1\" _title=\"GID\" expansion=\"1.0\" minimum_width=\"40\" resizable=\"true\" cell=\"string\" compare=\"id_compare\"/> \
-</ETableSpecification>";
-
-const gchar *net_group_spec = "\
-<ETableSpecification no-headers=\"true\" cursor-mode=\"line\"> \
-  <ETableColumn model_col=\"0\" _title=\"Group\" expansion=\"1.0\" minimum_width=\"20\" resizable=\"true\" cell=\"string\" compare=\"string\"/> \
-  <ETableState> \
-    <column source=\"0\"/> \
-    <grouping></grouping> \
-  </ETableState> \
-</ETableSpecification>";
-
-const gchar *net_user_spec = "\
-<ETableSpecification no-headers=\"true\" cursor-mode=\"line\"> \
-  <ETableColumn model_col=\"0\" _title=\"User\" expansion=\"1.0\" minimum_width=\"20\" resizable=\"true\" cell=\"string\" compare=\"string\"/> \
-  <ETableState> \
-    <column source=\"0\"/> \
-    <grouping></grouping> \
-  </ETableState> \
-</ETableSpecification>";
-
 /* e-table states. */
 
 const gchar *adv_user_state = "\
@@ -258,13 +213,13 @@ user_value_at (ETableModel *etm, int col, int row, void *model_data)
 		return NULL;
 
 	switch (col) {
-	case COL_USER_LOGIN:   return user_value_login (node); break;
-	case COL_USER_UID:     return user_value_uid_string (node); break;
-	case COL_USER_HOME:    return user_value_home (node); break;
-	case COL_USER_SHELL:   return user_value_shell (node); break;
-	case COL_USER_COMMENT: return user_value_comment (node); break;
-	case COL_USER_GROUP:   return user_value_group (node); break;
-	case COL_USER_GID:     return user_value_gid_string (node); break;
+	case COL_USER_LOGIN:   return user_value_login_peek (node); break;
+	case COL_USER_UID:     return user_value_uid_string_peek (node); break;
+	case COL_USER_HOME:    return user_value_home_peek (node); break;
+	case COL_USER_SHELL:   return user_value_shell_peek (node); break;
+	case COL_USER_COMMENT: return user_value_comment_peek (node); break;
+	case COL_USER_GROUP:   return user_value_group_peek (node); break;
+	case COL_USER_GID:     return user_value_gid_string_peek (node); break;
 
 	case COL_USER_COLOR:   return get_row_color (etm, row); break;
 
@@ -286,8 +241,8 @@ group_value_at (ETableModel *etm, int col, int row, void *model_data)
 
 	switch (col)
 	{
-	case COL_GROUP_NAME: return group_value_name (node); break;
-	case COL_GROUP_GID:  return group_value_gid_string (node); break;
+	case COL_GROUP_NAME: return group_value_name_peek (node); break;
+	case COL_GROUP_GID:  return group_value_gid_string_peek (node); break;
 		
 	case COL_USER_COLOR: return get_row_color (etm, row); break;
 		
@@ -554,7 +509,9 @@ create_user_table (void)
 
 	spec = xst_conf_get_string (tool, "user_spec");
 	if (!spec) {
-		spec = g_strdup (user_spec);
+		spec = xst_ui_load_etspec (tool->etspecs_common_path, USER_TABLE_SPEC);
+		if (!spec)
+			g_error ("create_user_table: Couldn't create table.");
 		xst_conf_set_string (tool, "user_spec", spec);
 	}
 
@@ -608,7 +565,9 @@ create_group_table (void)
 
 	spec = xst_conf_get_string (tool, "group_spec");
 	if (!spec) {
-		spec = g_strdup (group_spec);
+		spec = xst_ui_load_etspec (tool->etspecs_common_path, GROUP_TABLE_SPEC);
+		if (!spec)
+			g_error ("create_user_table: Couldn't create table.");
 		xst_conf_set_string (tool, "group_spec", spec);
 	}
 
@@ -643,7 +602,8 @@ create_network_group_table (GtkWidget *paned)
 {
 	ETable *table;
 	ETableModel *model;
-
+	gchar *spec;
+	
 	model = e_table_memory_callbacks_new (col_count,
 					      net_group_value_at,
 					      set_value_at,
@@ -655,7 +615,17 @@ create_network_group_table (GtkWidget *paned)
 					      value_to_string,
 					      GINT_TO_POINTER (TABLE_NET_GROUP));
 
-	net_group_table = e_table_scrolled_new (E_TABLE_MODEL (model), NULL, net_group_spec, NULL);
+	spec = xst_conf_get_string (tool, "net_group_spec");
+	if (!spec) {
+		spec = xst_ui_load_etspec (tool->etspecs_common_path, NET_GROUP_TABLE_SPEC);
+		if (!spec)
+			g_error ("create_user_table: Couldn't create table.");
+		xst_conf_set_string (tool, "net_group_spec", spec);
+	}
+	net_group_table = e_table_scrolled_new (E_TABLE_MODEL (model), NULL, spec, NULL);
+
+	g_free (spec);
+
 	table = e_table_scrolled_get_table (E_TABLE_SCROLLED (net_group_table));
 	gtk_signal_connect (GTK_OBJECT (table), "cursor_change", cursor_change, NULL);
 	gtk_signal_connect (GTK_OBJECT (table), "cursor_change", net_group_cursor_change, NULL);
@@ -669,7 +639,8 @@ create_network_user_table (GtkWidget *paned)
 {
 	ETable *table;
 	ETableModel *model;
-
+	gchar *spec;
+	
 	model = e_table_memory_callbacks_new (col_count,
 					      net_user_value_at,
 					      set_value_at,
@@ -681,7 +652,17 @@ create_network_user_table (GtkWidget *paned)
 					      value_to_string,
 					      GINT_TO_POINTER (TABLE_NET_USER));
 
-	net_user_table = e_table_scrolled_new (E_TABLE_MODEL (model), NULL, net_user_spec, NULL);
+	spec = xst_conf_get_string (tool, "net_user_spec");
+	if (!spec) {
+		spec = xst_ui_load_etspec (tool->etspecs_common_path, NET_USER_TABLE_SPEC);
+		if (!spec)
+			g_error ("create_user_table: Couldn't create table.");
+		xst_conf_set_string (tool, "net_user_spec", spec);
+	}
+	net_user_table = e_table_scrolled_new (E_TABLE_MODEL (model), NULL, spec, NULL);
+
+	g_free(spec);
+	
 	table = e_table_scrolled_get_table (E_TABLE_SCROLLED (net_user_table));
 	gtk_signal_connect (GTK_OBJECT (table), "cursor_activated", cursor_change, NULL);
 
