@@ -33,6 +33,8 @@
 
 extern XstTool *tool;
 
+static void user_account_gui_setup_profile (UserAccountGui *gui);
+
 static void
 user_account_gui_add (GtkButton *button, gpointer data)
 {
@@ -104,6 +106,21 @@ user_account_gui_all_select (GtkCList *clist, gint row, gint column, GdkEventBut
 		gtk_widget_set_sensitive (GTK_WIDGET (gui->add), FALSE);
 }
 
+static void
+user_account_gui_profile_changed (GtkMenuShell *menushell, gpointer data)
+{
+	UserAccountGui *gui = data;
+	UserAccount *account;
+	gchar *profile;	
+
+	user_account_destroy (gui->account);
+	profile = xst_ui_option_menu_get_selected_string (gui->profile_menu);
+	account = user_account_new (profile);
+	g_free (profile);
+	gui->account = account;
+	user_account_gui_setup_profile (gui);
+}
+
 enum {
 	NOTEBOOK_PAGE_MANUAL,
 	NOTEBOOK_PAGE_RANDOM,
@@ -193,12 +210,17 @@ user_account_gui_new (UserAccount *account, GtkWidget *parent)
 	gui->basic_frame = glade_xml_get_widget (gui->xml, "user_settings_basic");
 	gui->name    = GTK_ENTRY (glade_xml_get_widget (gui->xml, "user_settings_name"));
 	gui->comment = GTK_ENTRY (glade_xml_get_widget (gui->xml, "user_settings_comment"));
+	gui->contact_frame = glade_xml_get_widget (gui->xml, "user_settings_contact_info");
+	gui->office  = GTK_ENTRY (glade_xml_get_widget (gui->xml, "user_settings_office"));
+	gui->wphone  = GTK_ENTRY (glade_xml_get_widget (gui->xml, "user_settings_wphone"));
+	gui->hphone  = GTK_ENTRY (glade_xml_get_widget (gui->xml, "user_settings_hphone"));
 	gui->home    = GTK_ENTRY (glade_xml_get_widget (gui->xml, "user_settings_home"));
 	gui->shell   = GTK_COMBO (glade_xml_get_widget (gui->xml, "user_settings_shell"));
 	gui->uid     = GTK_SPIN_BUTTON (glade_xml_get_widget (gui->xml, "user_settings_uid"));
 	gui->advanced = glade_xml_get_widget (gui->xml, "user_settings_advanced");
 	gui->profile_box = glade_xml_get_widget (gui->xml, "user_settings_profile_box");
 	gui->profile_menu = GTK_OPTION_MENU (glade_xml_get_widget (gui->xml, "user_settings_profile_menu"));
+	gui->profile_button = glade_xml_get_widget (gui->xml, "user_settings_profile_button");
 
 	gui->group_box = glade_xml_get_widget (gui->xml, "user_settings_group_box");
 	gui->group_extra = glade_xml_get_widget (gui->xml, "user_settings_group_extra");
@@ -223,6 +245,9 @@ user_account_gui_new (UserAccount *account, GtkWidget *parent)
 	gui->max  = GTK_SPIN_BUTTON (glade_xml_get_widget (gui->xml, "user_passwd_max"));
 	gui->days = GTK_SPIN_BUTTON (glade_xml_get_widget (gui->xml, "user_passwd_days"));
 
+	gtk_signal_connect (GTK_OBJECT (gui->profile_button), "clicked",
+			    GTK_SIGNAL_FUNC (profile_table_run), NULL);
+	
 	gtk_signal_connect (GTK_OBJECT (gui->add), "clicked",
 			    GTK_SIGNAL_FUNC (user_account_gui_add), gui);
 	gtk_signal_connect (GTK_OBJECT (gui->remove), "clicked",
@@ -252,6 +277,12 @@ user_account_gui_new (UserAccount *account, GtkWidget *parent)
 
 	gtk_signal_connect (GTK_OBJECT (gui->name), "activate",
 			    GTK_SIGNAL_FUNC (user_account_grab_focus), (gpointer) gui->comment);
+	gtk_signal_connect (GTK_OBJECT (gui->comment), "activate",
+			    GTK_SIGNAL_FUNC (user_account_grab_focus), (gpointer) gui->office);
+	gtk_signal_connect (GTK_OBJECT (gui->office), "activate",
+			    GTK_SIGNAL_FUNC (user_account_grab_focus), (gpointer) gui->wphone);
+	gtk_signal_connect (GTK_OBJECT (gui->wphone), "activate",
+			    GTK_SIGNAL_FUNC (user_account_grab_focus), (gpointer) gui->hphone);
 	gtk_signal_connect (GTK_OBJECT (gui->pwd1), "activate",
 			    GTK_SIGNAL_FUNC (user_account_grab_focus), (gpointer) gui->pwd2);
 	gtk_signal_connect (GTK_OBJECT (gui->uid), "activate",
@@ -306,10 +337,47 @@ user_account_groups_setup (GtkCombo *combo, xmlNodePtr node)
 	g_list_free (items);
 }
 
+static void
+user_account_comment_setup (UserAccountGui *gui)
+{
+	gint i;
+	gchar **comment = gui->account->comment;
+	GtkEntry *entries[] = {
+		GTK_ENTRY (gui->comment),
+		GTK_ENTRY (gui->office),
+		GTK_ENTRY (gui->wphone),
+		GTK_ENTRY (gui->hphone)
+	};
+
+	if (!comment)
+		return;
+	
+	for (i = 0; i < 4; i++) {
+		if (comment[i] == NULL)
+			break;
+		else
+			xst_ui_entry_set_text (entries[i], comment[i]);
+	}
+}
+
+static void
+user_account_gui_setup_profile (UserAccountGui *gui)
+{
+	UserAccount *account = gui->account;
+	
+	xst_ui_entry_set_text (gui->home, account->home);
+	xst_ui_entry_set_text (GTK_ENTRY (gui->shell->entry), account->shell);
+	gtk_spin_button_set_value (gui->uid, atoi (account->uid));
+	xst_ui_entry_set_text (GTK_ENTRY (gui->group->entry), account->group);
+	gtk_spin_button_set_value (gui->min, account->pwd_mindays);
+	gtk_spin_button_set_value (gui->max, account->pwd_maxdays);
+	gtk_spin_button_set_value (gui->days, account->pwd_warndays);
+}
+
 static void
 setup_advanced_add (UserAccountGui *gui, GtkWidget *notebook)
 {
-	GtkWidget *box, *label;
+	GtkWidget *box, *label, *menu_item;
 	GSList *list = profile_table_get_list ();
 	Profile *pf = profile_table_get_profile (NULL);
 
@@ -319,6 +387,10 @@ setup_advanced_add (UserAccountGui *gui, GtkWidget *notebook)
 	gtk_box_set_child_packing (GTK_BOX (box),
 				   GTK_WIDGET (gui->basic_frame),
 				   FALSE, FALSE, 0, GTK_PACK_START);
+	gtk_widget_reparent (GTK_WIDGET (gui->contact_frame), box);
+	gtk_box_set_child_packing (GTK_BOX (box),
+				   GTK_WIDGET (gui->contact_frame),
+				   FALSE, FALSE, 0, GTK_PACK_START);	
 	gtk_widget_reparent (GTK_WIDGET (gui->profile_box), box);
 	gtk_box_set_child_packing (GTK_BOX (box),
 				   GTK_WIDGET (gui->profile_box),
@@ -342,7 +414,9 @@ setup_advanced_add (UserAccountGui *gui, GtkWidget *notebook)
 	gtk_widget_show_all (box);
 
 	while (list) {
-		xst_ui_option_menu_add_string (gui->profile_menu, list->data);
+		menu_item = xst_ui_option_menu_add_string (gui->profile_menu, list->data);
+		gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
+				    GTK_SIGNAL_FUNC (user_account_gui_profile_changed), gui);
 		list = list->next;
 	}
 	g_slist_free (list);
@@ -352,16 +426,15 @@ setup_advanced_add (UserAccountGui *gui, GtkWidget *notebook)
 static void
 setup_basic_add (UserAccountGui *gui, GtkWidget *notebook)
 {
-	GtkWidget *widget, *container;
+	GtkWidget *container;
 	
 	container = glade_xml_get_widget (gui->xml, "user_druid_identity");
-	widget = glade_xml_get_widget (gui->xml, "user_settings_basic");
-	gtk_widget_reparent (widget, container);
+	gtk_widget_reparent (gui->basic_frame, container);
+	gtk_widget_reparent (gui->contact_frame, container);
 	gtk_widget_show_all (container);
 
 	container = glade_xml_get_widget (gui->xml, "user_druid_password");
-	widget = glade_xml_get_widget (gui->xml, "user_passwd_frame");
-	gtk_widget_reparent (widget, container);
+	gtk_widget_reparent (gui->pwd_frame, container);
 	gtk_widget_show_all (container);
 }
 
@@ -372,9 +445,13 @@ setup_basic (UserAccountGui *gui, GtkWidget *notebook)
 
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 
+	label = glade_xml_get_widget (gui->xml, "user_settings_comment_label");
+	gtk_label_set_text (GTK_LABEL (label), N_("Real name:"));
+	
 	/* Reparent widgets */
 	box = gtk_vbox_new (FALSE, 3);
 	gtk_widget_reparent (GTK_WIDGET (gui->basic_frame), box);
+	gtk_widget_reparent (GTK_WIDGET (gui->contact_frame), box);
 	gtk_widget_reparent (GTK_WIDGET (gui->pwd_frame), box);
 	label = gtk_label_new (_("Identity"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), box, label);
@@ -389,6 +466,7 @@ setup_advanced (UserAccountGui *gui, GtkWidget *notebook)
 	/* Reparent widgets */
 	box = gtk_vbox_new (FALSE, 3);
 	gtk_widget_reparent (GTK_WIDGET (gui->basic_frame), box);
+	gtk_widget_reparent (GTK_WIDGET (gui->contact_frame), box);
 	gtk_widget_reparent (GTK_WIDGET (gui->advanced), box);
 	label = gtk_label_new (_("Identity"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), box, label);
@@ -418,27 +496,21 @@ user_account_gui_setup (UserAccountGui *gui, GtkWidget *top)
 	
 	user_account_shells_setup (gui);
 	user_account_groups_setup (gui->group, account->node);
+	user_account_comment_setup (gui);
 	
-	my_gtk_entry_set_text (gui->name, account->name);
-	my_gtk_entry_set_text (gui->comment, account->comment);
-	my_gtk_entry_set_text (gui->home, account->home);
-	my_gtk_entry_set_text (GTK_ENTRY (gui->shell->entry), account->shell);
-	gtk_spin_button_set_value (gui->uid, atoi (account->uid));
+	xst_ui_entry_set_text (gui->name, account->name);
+
+	user_account_gui_setup_profile (gui);
 
 	gtk_clist_set_auto_sort (gui->all, TRUE);
 	gtk_clist_set_auto_sort (gui->member, TRUE);
 	
-	my_gtk_entry_set_text (GTK_ENTRY (gui->group->entry), account->group);
 	my_gtk_clist_append_items (gui->member, (GList *)account->extra_groups);
 	/* Others */
 	users = get_group_list ("name", account->node);
 	items = my_g_list_remove_duplicates (users, (GList *)account->extra_groups);
 	my_gtk_clist_append_items (gui->all, items);
 
-	gtk_spin_button_set_value (gui->min, account->pwd_mindays);
-	gtk_spin_button_set_value (gui->max, account->pwd_maxdays);
-	gtk_spin_button_set_value (gui->days, account->pwd_warndays);
-
 	if (account->password && (strlen (account->password) > 2)) {
 		gtk_signal_handler_block_by_func (GTK_OBJECT (gui->pwd1),
 						  user_account_passwd_changed,
@@ -485,6 +557,25 @@ user_account_gui_setup (UserAccountGui *gui, GtkWidget *top)
 	}
 }
 
+static gchar**
+user_account_gui_save_comment (UserAccountGui *gui)
+{
+	gchar *buf;
+	gchar **val;
+
+	buf = g_strjoin (",",
+			 gtk_entry_get_text (gui->comment),
+			 gtk_entry_get_text (gui->office),
+			 gtk_entry_get_text (gui->wphone),
+			 gtk_entry_get_text (gui->hphone),
+			 NULL);
+
+	val = g_strsplit (buf, ",", 4);
+	g_free (buf);
+	
+	return val;
+}
+
 gboolean
 user_account_gui_save (UserAccountGui *gui)
 {
@@ -499,48 +590,21 @@ user_account_gui_save (UserAccountGui *gui)
 	account->new = gui->account->new;
 	
 	buf = gtk_entry_get_text (gui->name);
-	if ((error = check_user_login (node, buf)))
-		goto err;
 	account->name = g_strdup (buf);
 	
-	buf = gtk_entry_get_text (gui->comment);
-	if ((error = check_user_comment (node, buf)))
-		goto err;
-	account->comment = g_strdup (buf);
+	account->comment = user_account_gui_save_comment (gui);
 	
 	buf = gtk_entry_get_text (gui->home);
-	if ((error = check_user_home (node, buf)))
-		goto err;
 	account->home = g_strdup (buf);
 	
 	buf = gtk_entry_get_text (GTK_ENTRY (gui->shell->entry));
-	if ((error = check_user_shell (node, buf)))
-		goto err;
 	account->shell = g_strdup (buf);
 	
 	buf = g_strdup_printf ("%d", gtk_spin_button_get_value_as_int (gui->uid));
-	if ((error = check_user_uid (node, buf))) {
-		g_free (buf);
-		goto err;
-	}
 	account->uid = (buf);
 
 	buf = gtk_entry_get_text (GTK_ENTRY (gui->group->entry));
-	switch (check_user_group (account, buf, &error)) {
-	case -1: /* Name is not valid */
-		goto err;
-		break;
-	case 0: /* Valid, exists */		
-		account->group = g_strdup (buf);
-		break;
-	case 1: /* Valid, new */
-		account->group = g_strdup (buf);
-		break;
-	default:
-		g_warning ("user_account_gui_save: Shouldn't be here.");
-		break;
-	}
-	g_free (error);
+	account->group = g_strdup (buf);
 
 	/* Password */
 	if (gtk_toggle_button_get_active (gui->pwd_random)) {
@@ -555,9 +619,11 @@ user_account_gui_save (UserAccountGui *gui)
 			gchar *buf1 = gtk_entry_get_text (gui->pwd1);
 
 			buf = gtk_entry_get_text (gui->pwd2);
-			if ((error = passwd_check (buf1, buf, gtk_toggle_button_get_active (gui->quality))))
-				goto err;
-			else
+			if ((error = passwd_check (buf1, buf, gtk_toggle_button_get_active (gui->quality)))) {
+				user_account_gui_error (parent, error);
+				user_account_destroy (account);
+				return FALSE;
+			} else
 				account->password = g_strdup (buf);
 		} else
 			account->password = NULL;
@@ -570,16 +636,16 @@ user_account_gui_save (UserAccountGui *gui)
 	account->extra_groups = NULL;
 	while (gtk_clist_get_text (gui->member, row++, 0, &buf))
 		account->extra_groups = g_slist_prepend (account->extra_groups, buf);
-	
-	user_account_destroy (gui->account);
-	gui->account = account;
-	
-	return TRUE;
 
-err:
-	user_account_gui_error (parent, error);
-	user_account_destroy (account);
-	return FALSE;
+	if ((error = user_account_check (account))) {
+		user_account_gui_error (parent, error);
+		user_account_destroy (account);
+		return FALSE;
+	} else {
+		user_account_destroy (gui->account);
+		gui->account = account;
+		return TRUE;
+	}
 }
 
 void
